aboutsummaryrefslogtreecommitdiffstats
path: root/packet-h261.c
diff options
context:
space:
mode:
authorGilbert Ramirez <gram@alumni.rice.edu>2002-01-29 17:18:06 +0000
committerGilbert Ramirez <gram@alumni.rice.edu>2002-01-29 17:18:06 +0000
commite7148a16b46cf2549adff9e4f6230423ac7ec211 (patch)
tree8c69aecea5abdbb8c0a2f35abe55c421f4115a0e /packet-h261.c
parent638c1bfba8a7796ac6f01735b72c19f06ff14828 (diff)
Fixes from Joe Litman <jlitman@fvc.com>
svn path=/trunk/; revision=4621
Diffstat (limited to 'packet-h261.c')
-rw-r--r--packet-h261.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/packet-h261.c b/packet-h261.c
index 125bc123f9..8e5e5a7982 100644
--- a/packet-h261.c
+++ b/packet-h261.c
@@ -2,7 +2,7 @@
*
* Routines for ITU-T Recommendation H.261 dissection
*
- * $Id: packet-h261.c,v 1.12 2002/01/24 09:20:48 guy Exp $
+ * $Id: packet-h261.c,v 1.13 2002/01/29 17:18:06 gram Exp $
*
* Copyright 2000, Philips Electronics N.V.
* Andreas Sikkema <andreas.sikkema@philips.com>
@@ -89,7 +89,7 @@ dissect_h261( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
/* SBIT 1st octet, 3 bits */
proto_tree_add_uint( h261_tree, hf_h261_sbit, tvb, offset, 1, tvb_get_guint8( tvb, offset ) >> 5 );
/* EBIT 1st octet, 3 bits */
- proto_tree_add_item( h261_tree, hf_h261_ebit, tvb, offset, 1, ( tvb_get_guint8( tvb, offset ) << 3 ) >> 5 );
+ proto_tree_add_uint( h261_tree, hf_h261_ebit, tvb, offset, 1, ( tvb_get_guint8( tvb, offset ) << 3 ) >> 5 );
/* I flag, 1 bit */
proto_tree_add_boolean( h261_tree, hf_h261_ibit, tvb, offset, 1, tvb_get_guint8( tvb, offset ) & 2 );
/* V flag, 1 bit */
@@ -105,15 +105,15 @@ dissect_h261( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
offset++;
/* QUANT 3rd octet, 5 bits (starting at bit 2!) */
- proto_tree_add_uint( h261_tree, hf_h261_mbap, tvb, offset, 1, tvb_get_guint8( tvb, offset ) & 124 );
- /* HMDV 3rd octet 2 bits, 4th octet 3 bits */
- proto_tree_add_uint( h261_tree, hf_h261_mbap, tvb, offset, 1,
+ proto_tree_add_uint( h261_tree, hf_h261_quant, tvb, offset, 1, tvb_get_guint8( tvb, offset ) & 124 );
+ /* HMVD 3rd octet 2 bits, 4th octet 3 bits */
+ proto_tree_add_uint( h261_tree, hf_h261_hmvd, tvb, offset, 1,
( ( tvb_get_guint8( tvb, offset ) << 4) >> 4 )
+ ( tvb_get_guint8( tvb, offset ) >> 5 ) );
offset++;
/* VMVD 4th octet, last 5 bits */
- proto_tree_add_uint( h261_tree, hf_h261_mbap, tvb, offset, 1, tvb_get_guint8( tvb, offset ) & 31 );
+ proto_tree_add_uint( h261_tree, hf_h261_vmvd, tvb, offset, 1, tvb_get_guint8( tvb, offset ) & 31 );
offset++;
/* The rest of the packet is the H.261 stream */